==> haskell-lua-arbitrary-1.0.1.1-101-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lua-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lua-arbitrary
version:              1.0.1.1
visibility:           public
id:                   lua-arbitrary-1.0.1.1-HXw7K1xREIP6qQeK10THL
key:                  lua-arbitrary-1.0.1.1-HXw7K1xREIP6qQeK10THL
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Arbitrary instances for Lua types.
description:
    Provides instances for QuickCheck'\''s \"Arbitrary\"
    typeclass.

category:             Foreign
abi:                  254eb4a786d68dffe8ffbf75998ef415
exposed:              True
exposed-modules:      Lua.Arbitrary
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lua-arbitrary-1.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lua-arbitrary-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lua-arbitrary-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lua-arbitrary
hs-libraries:         HSlua-arbitrary-1.0.1.1-HXw7K1xREIP6qQeK10THL
depends:
    QuickCheck-2.15.0.1-KOgxsDPQQ5yBOLUqP0mecl base-4.17.2.1
    lua-2.3.3-Ea4BE7kc61GjhtVAaItrr

haddock-interfaces:
    /usr/share/doc/haskell-lua-arbitrary/html/lua-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-lua-arbitrary/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lua-arbitrary-1.0.1.1-102-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lua-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lua-arbitrary
version:              1.0.1.1
visibility:           public
id:                   lua-arbitrary-1.0.1.1-RljvdGliDMGLkfNaYitJL
key:                  lua-arbitrary-1.0.1.1-RljvdGliDMGLkfNaYitJL
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Arbitrary instances for Lua types.
description:
    Provides instances for QuickCheck'\''s \"Arbitrary\"
    typeclass.

category:             Foreign
abi:                  6312ddbea7de3a45af5298d7a3fed3b9
exposed:              True
exposed-modules:      Lua.Arbitrary
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lua-arbitrary-1.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lua-arbitrary-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lua-arbitrary-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lua-arbitrary
hs-libraries:         HSlua-arbitrary-1.0.1.1-RljvdGliDMGLkfNaYitJL
depends:
    QuickCheck-2.15.0.1-4O3a6KCv0r3IEepy258gow base-4.17.2.1
    lua-2.3.3-Hl6t7b5iy8qpyU75C96gB

haddock-interfaces:
    /usr/share/doc/haskell-lua-arbitrary/html/lua-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-lua-arbitrary/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
